@@ -86,40 +86,41 @@ def setup(settings_path=None, **settings_patches):
           ' libcap-devel libuuid-devel libev-devel python-greenlet-devel httpd-devel')
 
     # Install Uwsgi
-    with temporary_directory(identifier=IDENTIFIER, prefix='init_remote_base') as tmp_directory:
-        with lcd(tmp_directory):
-            print section_title('Install uwsgi and mod_uwsgi')
-            # Get source code
-            local('wget http://projects.unbit.it/downloads/uwsgi-lts.tar.gz')
-            local('tar -zxf uwsgi-lts.tar.gz')
-            try:
-                uwsgi_src_folder = [path for path in os.listdir(tmp_directory)
-                                    if path.startswith('uwsgi-') and '-lts' not in path][0]
-            except IndexError:
-                abort('Failed to extract uwsgi source folder')
-                return
+    if not os.path.exists('/usr/local/bin/uwsgi'):
+        with temporary_directory(identifier=IDENTIFIER, prefix='init_remote_base') as tmp_directory:
+            with lcd(tmp_directory):
+                print section_title('Install uwsgi and mod_uwsgi')
+                # Get source code
+                local('wget http://projects.unbit.it/downloads/uwsgi-lts.tar.gz')
+                local('tar -zxf uwsgi-lts.tar.gz')
+                try:
+                    uwsgi_src_folder = [path for path in os.listdir(tmp_directory)
+                                        if path.startswith('uwsgi-') and '-lts' not in path][0]
+                except IndexError:
+                    abort('Failed to extract uwsgi source folder')
+                    return
 
-            with lcd(uwsgi_src_folder):
-                # Create build configuration
-                local('mkdir -p /usr/local/lib/uwsgi')
-                config = ConfigParser.ConfigParser()
-                config.add_section('uwsgi')
-                config.set('uwsgi', 'main_plugin', 'python')
-                config.set('uwsgi', 'inherit', 'base')
-                config.set('uwsgi', 'plugin_dir', '/usr/local/lib/uwsgi')
-                with open(os.path.join(tmp_directory, uwsgi_src_folder, 'buildconf/beanstalk.ini'), 'w') as f:
-                    config.write(f)
-                # Build and install
-                local('python uwsgiconfig.py --build beanstalk')
-                local('cp uwsgi /usr/local/bin/uwsgi')
-                if not os.path.exists('/usr/bin/uwsgi'):
-                    local('ln -s /usr/local/bin/uwsgi /usr/bin/uwsgi')
-                local('mkdir -p /var/run/beanstalk')
-                local('cp %s /etc/init.d/beanstalk' % os.path.join(BEANSTALK_ROOT_PATH, 'static/beanstalk_init.sh'))
-                local('chmod +x /etc/init.d/beanstalk')
-                # mod_uwsgi
-                local('apxs -i -c apache2/mod_uwsgi.c')
-                local('echo "LoadModule uwsgi_module modules/mod_uwsgi.so" > /etc/httpd/conf.d/uwsgi.conf')
+                with lcd(uwsgi_src_folder):
+                    # Create build configuration
+                    local('mkdir -p /usr/local/lib/uwsgi')
+                    config = ConfigParser.ConfigParser()
+                    config.add_section('uwsgi')
+                    config.set('uwsgi', 'main_plugin', 'python')
+                    config.set('uwsgi', 'inherit', 'base')
+                    config.set('uwsgi', 'plugin_dir', '/usr/local/lib/uwsgi')
+                    with open(os.path.join(tmp_directory, uwsgi_src_folder, 'buildconf/beanstalk.ini'), 'w') as f:
+                        config.write(f)
+                    # Build and install
+                    local('python uwsgiconfig.py --build beanstalk')
+                    local('cp uwsgi /usr/local/bin/uwsgi')
+                    if not os.path.exists('/usr/bin/uwsgi'):
+                        local('ln -s /usr/local/bin/uwsgi /usr/bin/uwsgi')
+                    local('mkdir -p /var/run/beanstalk')
+                    local('cp %s /etc/init.d/beanstalk' % os.path.join(BEANSTALK_ROOT_PATH, 'static/beanstalk_init.sh'))
+                    local('chmod +x /etc/init.d/beanstalk')
+                    # mod_uwsgi
+                    local('apxs -i -c apache2/mod_uwsgi.c')
+                    local('echo "LoadModule uwsgi_module modules/mod_uwsgi.so" > /etc/httpd/conf.d/uwsgi.conf')
 
     # Do you have user "beanstalk"?
     with settings(hide('everything'), warn_only=True):
@@ -169,15 +170,16 @@ def setup(settings_path=None, **settings_patches):
     # Apache conf
     beanstalk_apache_conf_template = os.path.join(BEANSTALK_ROOT_PATH, 'static/beanstalk_apache.conf')
     beanstalk_apache_conf = render_file(
-        beanstalk_apache_conf_template, beanstalk_settings, BEANSTALK_APP_APACHE_CONF=apache_conf_path())
+        beanstalk_apache_conf_template, beanstalk_settings)
     with open('/etc/httpd/conf.d/beanstalk.conf', 'w') as f:
         f.write(beanstalk_apache_conf)
     local('echo "# Beanstalk Apache conf" > %s' % apache_conf_path())
     local('chown beanstalk:beanstalk %s' % apache_conf_path())
+    local('ln -s %s /etc/httpd/conf.d/beanstalk_app.conf' % apache_conf_path())
 
     local('chown -R beanstalk:beanstalk %s' % beanstalk_stack_base)
     local('/etc/init.d/sshd restart')
-    local('/etc/init.d/httpd reload')
+    local('/etc/init.d/httpd restart')
 
 
 @task
